commandmodule - Command Application Packet Creator
======================================

The commandmodule Faraday Python module is a collection of packet creation functions that create command application packets.

.. automodule:: commandmodule
    :members:
